#
# spec file for package python3-autopep8
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-autopep8
Version:        1.2
Release:        3.2
Url:            https://github.com/hhatto/autopep8
Summary:        Automatic generated to pep8 checked code
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/a/autopep8/autopep8-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements:
BuildRequires:  python3-pep8
Requires:       python3-pep8
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
Autopep8 is automatic generated to pep8 checked code.
This is old style tool, wrapped pep8 via subprocess module.

%prep
%setup -q -n autopep8-%{version}
sed -i '1d' autopep8.py # Remove she-bang line
sed -i "s/autopep8 =/autopep8-%{py3_ver} =/" setup.py  # Add py3_ver suffix to binary

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
ln -s %{_bindir}/autopep8-%{py3_ver} %{buildroot}%{_bindir}/autopep8

%check
# need to set locale to avoid UnicodeEncodeError
export LANG="en_US.UTF-8"
python3 setup.py test

%pre
# Since /usr/bin/autopep8 became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/autopep8 ] || rm -f %{_bindir}/autopep8

%post
update-alternatives --install %{_bindir}/autopep8 autopep8 %{_bindir}/autopep8-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove autopep8 %{_bindir}/autopep8-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc README.rst AUTHORS.rst
%ghost %{_bindir}/autopep8
%if 0%{?suse_version} >= 1230
%ghost %{_sysconfdir}/alternatives/autopep8
%endif
%{_bindir}/autopep8-%{py3_ver}
%{python3_sitelib}/autopep8.py*
%{python3_sitelib}/autopep8-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/__pycache__/autopep8.*

%changelog
* Sun Aug  9 2015 arun@gmx.de
- specfile: add AUTHORS.rst file
- update to version 1.2:
  * exec update_readme.py
  * Expose "argv"
  * Use new pep8 URL
  * Clean up
  * Generalize to handle dots in E712 and E713
  * Document limitations
  * Remove unused tests
  * Use actual parameter name
  * Strip whitespace in error codes
  * Support multiprocessing on Windows
  * Avoid issue #175 for now
  * Make this work on Python 2.6
  * Remove unnecessary check
  * Disable for now
  * Add failing example
  * Use same version of Python throughout
  * Indent
  * Fix #183
  * Fix some of #195
  * Clean up import
  * Clean up variable names
  * Add "--line-range" for consistent naming
  * Check for bad options
  * Update for dictionary-option change
  * Support dictionary options
  * Add test for issue #175
  * Narrow down the bug avoidance
  * Avoid buggy "--range" case for now
  * Separate W391 from global fix
  * Avoid breaking lambda at awkward location
  * Generalize
  * Avoid breaking after unary operator
  * Move the "rstrip()" to a better place
  * Avoid add trailing in double aggressive mode
  * Avoid growing the line length
  * Remove redundant option
  * Put code in main function
  * Support Python 3 in Vim usage example
  * Set for bb81d1922970c485edd5dd75f279120c709dc1fe
  * Modify E309 to reflect change in PEP 257
  * Update with latest pep8
* Thu Feb 26 2015 arun@gmx.de
- update to version 1.1.1:
  * fix fail test when use sdist files
  * ignore coverage data
  * Update due to change in "pep8"
  * Suppress false positive
  * Test against "LANG="
  * Fall back to "sys.getdefaultencoding()"
  * Increment copyright date
- changes from version 1.1:
  * Add note
  * Add for 5edb790ee5555e42992cb38885c9c72ad70a5918
  * Fix exclude in recursive mode
  * fix fix_e265 comment
  * Clean up
  * Add suppressions for Python 2
  * Format
  * Add future imports
  * Remove untested code
  * Remove broken and untested code
  * Put "and" in the right place
  * Format
  * Add missing "r"
  * Mention pep8
  * cln expand long test to multiline string
  * Add note
  * pep8 failure (E501 not picked up by autopep8?)
  * fix multi-line docstrings over range
  * cln remove comment indentation first
  * TST additional range comment test for comment followed by new line
  * FIX comments in line range are indented to match subsequent line
  * Simplify
  * Format
  * Use parentheses uniformly
  * Remove user-dependent test
  * Read configuration after filename normalization
  * Find configuration file correctly
  * Clean up
  * Clean up
  * Make tests safer
  * Clean up
  * Undo home directory expansion in documentation
  * Allowing leading "--" in configuration
  * Clean up
  * Add back Python 2.6 support
  * Add missing usage of "GLOBAL_CONFIG"
  * Set development version
  * Handle more errors
  * Use non-deprecated import
  * Document new options
  * Format
  * Remove unnecessary method
  * Revert 1f782659f13adf63969fb3d41bdbdf6cb56d148a
  * CLN remove _main
  * CLN remove pragma: no cover as not needed with coveralls cc @myint
  * CLN parse args twice, no manual arguments checking
  * FIX autocomplete for --global-config arg and with space sep
  * Use lowercase
  * Generalize
  * Remove bad backslash
  * Avoid getting into bad state due to E901
  * Remove flaky lib2to3 "import" fixer
  * API use --global-config and --ignore-local-config arguments
  * TST check passing arg overrides default/config
  * ENH add --config argument
  * Mention pep8 repository
  * Remove bad-syntax inducing code
  * Format
  * Clean up
  * Clean up
  * Remove no-longer-working script
  * include spaces in the 'class' or 'def' checks
  * improve e302 fix code
  * fix suite tests
  * fix infinite loop in e501 experimental_decorator unit test
  * extend E302 fix (comments before class definition)
  * fix #145
  * fix #161
* Thu Dec 11 2014 arun@gmx.de
- update to version 1.0.4:
  * Avoid extended E301 false positive
  * Avoid E309 false positive
  * Support W293
  * Support selecting E111
  * Handle trailing commas gracefully in "--ignore"
  * Clean up
  * Move "ws_comma" fixer to global fixes
  * Format
  * Pass in filename to lib2to3
  * Simplify
  * Simplify
  * Write to "sys.stdout" with desired encoding
  * Use '--experimental' for experimental tests.
  * Normalize 'for' and 'while' constructs so that they can be reformatted properly.
  * Document
  * Switch to development mode
  * Document "encoding" parameter
  * Give credit for patch
  * Fix whitespace
  * Fixed issue where the encoding was not correct when the contents of the file were passed directly a
  * ignore idea(for pycharm)
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 1.0.3
  + Upstream provides no changelog
* Fri May  9 2014 toddrme2178@gmail.com
- Update to 1.0.2:
  + Upstream provides no changelog
- Update to 1.0.1
- Update to 1.0.0
- Update to 0.9.7
- Update to 0.9.6
- Fix UnicodeDecodeError in unittests
- Only ghost /etc/alternatives on 12.3 or newer
* Tue Nov  5 2013 speilicke@suse.com
- Update to version 0.9.5:
  + Upstream provides no changelog
- Run testsuite
- Implement update-alternatives
* Thu Sep  6 2012 toddrme2178@gmail.com
- Restore BuildRequires: python3  This package depends on hash
  algorithms that are only available if python3 is installed,
  python3-devel will not pull them in.  Building will fail if
  BuildRequires: python3 is removed.
* Tue Aug 21 2012 highwaystar.ru@gmail.com
- python3 package added
